@@ -3,19 +3,13 @@ package org.acme.dynamodb;
 import java.util.List;
 
 import javax.inject.Inject;
-import javax.ws.rs.Consumes;
 import javax.ws.rs.GET;
 import javax.ws.rs.POST;
 import javax.ws.rs.Path;
-import javax.ws.rs.PathParam;
-import javax.ws.rs.Produces;
-import javax.ws.rs.core.MediaType;
 
 import io.smallrye.mutiny.Uni;
 
 @Path("/async-fruits")
-@Produces(MediaType.APPLICATION_JSON)
-@Consumes(MediaType.APPLICATION_JSON)
 public class FruitAsyncResource {
 
     @Inject
@@ -28,7 +22,7 @@ public class FruitAsyncResource {
 
     @GET
     @Path("{name}")
-    public Uni<Fruit> getSingle(@PathParam("name") String name) {
+    public Uni<Fruit> getSingle(String name) {
         return service.get(name);
     }
 
