@@ -3,7 +3,6 @@ package org.acme.testcoverage;
 import javax.inject.Inject;
 import javax.ws.rs.GET;
 import javax.ws.rs.Path;
-import javax.ws.rs.PathParam;
 import javax.ws.rs.Produces;
 import javax.ws.rs.core.MediaType;
 
@@ -20,7 +19,7 @@ public class GreetingResource {
     @GET
     @Produces(MediaType.TEXT_PLAIN)
     @Path("/greeting/{name}")
-    public String greeting(@PathParam("name") String name) {
+    public String greeting(String name) {
         return service.greeting(name);
     }
 
@@ -29,4 +28,4 @@ public class GreetingResource {
     public String hello() {
         return "hello";
     }
-}
\ No newline at end of file
+}
